# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.radar._account_evaluation_create_params import (
        AccountEvaluationCreateParams as AccountEvaluationCreateParams,
        AccountEvaluationCreateParamsLoginInitiated as AccountEvaluationCreateParamsLoginInitiated,
        AccountEvaluationCreateParamsLoginInitiatedClientDeviceMetadataDetails as AccountEvaluationCreateParamsLoginInitiatedClientDeviceMetadataDetails,
        AccountEvaluationCreateParamsLoginInitiatedClientDeviceMetadataDetailsData as AccountEvaluationCreateParamsLoginInitiatedClientDeviceMetadataDetailsData,
        AccountEvaluationCreateParamsRegistrationInitiated as AccountEvaluationCreateParamsRegistrationInitiated,
        AccountEvaluationCreateParamsRegistrationInitiatedClientDeviceMetadataDetails as AccountEvaluationCreateParamsRegistrationInitiatedClientDeviceMetadataDetails,
        AccountEvaluationCreateParamsRegistrationInitiatedClientDeviceMetadataDetailsData as AccountEvaluationCreateParamsRegistrationInitiatedClientDeviceMetadataDetailsData,
        AccountEvaluationCreateParamsRegistrationInitiatedCustomerData as AccountEvaluationCreateParamsRegistrationInitiatedCustomerData,
    )
    from stripe.params.radar._account_evaluation_modify_params import (
        AccountEvaluationModifyParams as AccountEvaluationModifyParams,
        AccountEvaluationModifyParamsLoginFailed as AccountEvaluationModifyParamsLoginFailed,
        AccountEvaluationModifyParamsLoginSucceeded as AccountEvaluationModifyParamsLoginSucceeded,
        AccountEvaluationModifyParamsRegistrationFailed as AccountEvaluationModifyParamsRegistrationFailed,
        AccountEvaluationModifyParamsRegistrationSucceeded as AccountEvaluationModifyParamsRegistrationSucceeded,
    )
    from stripe.params.radar._account_evaluation_retrieve_params import (
        AccountEvaluationRetrieveParams as AccountEvaluationRetrieveParams,
    )
    from stripe.params.radar._account_evaluation_update_params import (
        AccountEvaluationUpdateParams as AccountEvaluationUpdateParams,
        AccountEvaluationUpdateParamsLoginFailed as AccountEvaluationUpdateParamsLoginFailed,
        AccountEvaluationUpdateParamsLoginSucceeded as AccountEvaluationUpdateParamsLoginSucceeded,
        AccountEvaluationUpdateParamsRegistrationFailed as AccountEvaluationUpdateParamsRegistrationFailed,
        AccountEvaluationUpdateParamsRegistrationSucceeded as AccountEvaluationUpdateParamsRegistrationSucceeded,
    )
    from stripe.params.radar._customer_evaluation_create_params import (
        CustomerEvaluationCreateParams as CustomerEvaluationCreateParams,
        CustomerEvaluationCreateParamsEvaluationContext as CustomerEvaluationCreateParamsEvaluationContext,
        CustomerEvaluationCreateParamsEvaluationContextClientDetails as CustomerEvaluationCreateParamsEvaluationContextClientDetails,
        CustomerEvaluationCreateParamsEvaluationContextClientDetailsData as CustomerEvaluationCreateParamsEvaluationContextClientDetailsData,
        CustomerEvaluationCreateParamsEvaluationContextCustomerDetails as CustomerEvaluationCreateParamsEvaluationContextCustomerDetails,
        CustomerEvaluationCreateParamsEvaluationContextCustomerDetailsCustomerData as CustomerEvaluationCreateParamsEvaluationContextCustomerDetailsCustomerData,
    )
    from stripe.params.radar._customer_evaluation_modify_params import (
        CustomerEvaluationModifyParams as CustomerEvaluationModifyParams,
    )
    from stripe.params.radar._customer_evaluation_retrieve_params import (
        CustomerEvaluationRetrieveParams as CustomerEvaluationRetrieveParams,
    )
    from stripe.params.radar._customer_evaluation_update_params import (
        CustomerEvaluationUpdateParams as CustomerEvaluationUpdateParams,
    )
    from stripe.params.radar._early_fraud_warning_list_params import (
        EarlyFraudWarningListParams as EarlyFraudWarningListParams,
        EarlyFraudWarningListParamsCreated as EarlyFraudWarningListParamsCreated,
    )
    from stripe.params.radar._early_fraud_warning_retrieve_params import (
        EarlyFraudWarningRetrieveParams as EarlyFraudWarningRetrieveParams,
    )
    from stripe.params.radar._issuing_authorization_evaluation_create_params import (
        IssuingAuthorizationEvaluationCreateParams as IssuingAuthorizationEvaluationCreateParams,
        IssuingAuthorizationEvaluationCreateParamsAuthorizationDetails as IssuingAuthorizationEvaluationCreateParamsAuthorizationDetails,
        IssuingAuthorizationEvaluationCreateParamsCardDetails as IssuingAuthorizationEvaluationCreateParamsCardDetails,
        IssuingAuthorizationEvaluationCreateParamsCardholderDetails as IssuingAuthorizationEvaluationCreateParamsCardholderDetails,
        IssuingAuthorizationEvaluationCreateParamsMerchantDetails as IssuingAuthorizationEvaluationCreateParamsMerchantDetails,
        IssuingAuthorizationEvaluationCreateParamsNetworkDetails as IssuingAuthorizationEvaluationCreateParamsNetworkDetails,
        IssuingAuthorizationEvaluationCreateParamsTokenDetails as IssuingAuthorizationEvaluationCreateParamsTokenDetails,
        IssuingAuthorizationEvaluationCreateParamsVerificationDetails as IssuingAuthorizationEvaluationCreateParamsVerificationDetails,
    )
    from stripe.params.radar._payment_evaluation_create_params import (
        PaymentEvaluationCreateParams as PaymentEvaluationCreateParams,
        PaymentEvaluationCreateParamsClientDeviceMetadataDetails as PaymentEvaluationCreateParamsClientDeviceMetadataDetails,
        PaymentEvaluationCreateParamsClientDeviceMetadataDetailsData as PaymentEvaluationCreateParamsClientDeviceMetadataDetailsData,
        PaymentEvaluationCreateParamsCustomerDetails as PaymentEvaluationCreateParamsCustomerDetails,
        PaymentEvaluationCreateParamsPaymentDetails as PaymentEvaluationCreateParamsPaymentDetails,
        PaymentEvaluationCreateParamsPaymentDetailsMoneyMovementDetails as PaymentEvaluationCreateParamsPaymentDetailsMoneyMovementDetails,
        PaymentEvaluationCreateParamsPaymentDetailsMoneyMovementDetailsCard as PaymentEvaluationCreateParamsPaymentDetailsMoneyMovementDetailsCard,
        PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetails as PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetails,
        PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetailsBillingDetails as PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetailsBillingDetails,
        PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetailsBillingDetailsAddress as PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetailsBillingDetailsAddress,
        PaymentEvaluationCreateParamsPaymentDetailsShippingDetails as PaymentEvaluationCreateParamsPaymentDetailsShippingDetails,
        PaymentEvaluationCreateParamsPaymentDetailsShippingDetailsAddress as PaymentEvaluationCreateParamsPaymentDetailsShippingDetailsAddress,
    )
    from stripe.params.radar._value_list_create_params import (
        ValueListCreateParams as ValueListCreateParams,
    )
    from stripe.params.radar._value_list_delete_params import (
        ValueListDeleteParams as ValueListDeleteParams,
    )
    from stripe.params.radar._value_list_item_create_params import (
        ValueListItemCreateParams as ValueListItemCreateParams,
    )
    from stripe.params.radar._value_list_item_delete_params import (
        ValueListItemDeleteParams as ValueListItemDeleteParams,
    )
    from stripe.params.radar._value_list_item_list_params import (
        ValueListItemListParams as ValueListItemListParams,
        ValueListItemListParamsCreated as ValueListItemListParamsCreated,
    )
    from stripe.params.radar._value_list_item_retrieve_params import (
        ValueListItemRetrieveParams as ValueListItemRetrieveParams,
    )
    from stripe.params.radar._value_list_list_params import (
        ValueListListParams as ValueListListParams,
        ValueListListParamsCreated as ValueListListParamsCreated,
    )
    from stripe.params.radar._value_list_modify_params import (
        ValueListModifyParams as ValueListModifyParams,
    )
    from stripe.params.radar._value_list_retrieve_params import (
        ValueListRetrieveParams as ValueListRetrieveParams,
    )
    from stripe.params.radar._value_list_update_params import (
        ValueListUpdateParams as ValueListUpdateParams,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "AccountEvaluationCreateParams": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsLoginInitiated": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsLoginInitiatedClientDeviceMetadataDetails": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsLoginInitiatedClientDeviceMetadataDetailsData": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsRegistrationInitiated": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsRegistrationInitiatedClientDeviceMetadataDetails": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsRegistrationInitiatedClientDeviceMetadataDetailsData": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsRegistrationInitiatedCustomerData": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationModifyParams": (
        "stripe.params.radar._account_evaluation_modify_params",
        False,
    ),
    "AccountEvaluationModifyParamsLoginFailed": (
        "stripe.params.radar._account_evaluation_modify_params",
        False,
    ),
    "AccountEvaluationModifyParamsLoginSucceeded": (
        "stripe.params.radar._account_evaluation_modify_params",
        False,
    ),
    "AccountEvaluationModifyParamsRegistrationFailed": (
        "stripe.params.radar._account_evaluation_modify_params",
        False,
    ),
    "AccountEvaluationModifyParamsRegistrationSucceeded": (
        "stripe.params.radar._account_evaluation_modify_params",
        False,
    ),
    "AccountEvaluationRetrieveParams": (
        "stripe.params.radar._account_evaluation_retrieve_params",
        False,
    ),
    "AccountEvaluationUpdateParams": (
        "stripe.params.radar._account_evaluation_update_params",
        False,
    ),
    "AccountEvaluationUpdateParamsLoginFailed": (
        "stripe.params.radar._account_evaluation_update_params",
        False,
    ),
    "AccountEvaluationUpdateParamsLoginSucceeded": (
        "stripe.params.radar._account_evaluation_update_params",
        False,
    ),
    "AccountEvaluationUpdateParamsRegistrationFailed": (
        "stripe.params.radar._account_evaluation_update_params",
        False,
    ),
    "AccountEvaluationUpdateParamsRegistrationSucceeded": (
        "stripe.params.radar._account_evaluation_update_params",
        False,
    ),
    "CustomerEvaluationCreateParams": (
        "stripe.params.radar._customer_evaluation_create_params",
        False,
    ),
    "CustomerEvaluationCreateParamsEvaluationContext": (
        "stripe.params.radar._customer_evaluation_create_params",
        False,
    ),
    "CustomerEvaluationCreateParamsEvaluationContextClientDetails": (
        "stripe.params.radar._customer_evaluation_create_params",
        False,
    ),
    "CustomerEvaluationCreateParamsEvaluationContextClientDetailsData": (
        "stripe.params.radar._customer_evaluation_create_params",
        False,
    ),
    "CustomerEvaluationCreateParamsEvaluationContextCustomerDetails": (
        "stripe.params.radar._customer_evaluation_create_params",
        False,
    ),
    "CustomerEvaluationCreateParamsEvaluationContextCustomerDetailsCustomerData": (
        "stripe.params.radar._customer_evaluation_create_params",
        False,
    ),
    "CustomerEvaluationModifyParams": (
        "stripe.params.radar._customer_evaluation_modify_params",
        False,
    ),
    "CustomerEvaluationRetrieveParams": (
        "stripe.params.radar._customer_evaluation_retrieve_params",
        False,
    ),
    "CustomerEvaluationUpdateParams": (
        "stripe.params.radar._customer_evaluation_update_params",
        False,
    ),
    "EarlyFraudWarningListParams": (
        "stripe.params.radar._early_fraud_warning_list_params",
        False,
    ),
    "EarlyFraudWarningListParamsCreated": (
        "stripe.params.radar._early_fraud_warning_list_params",
        False,
    ),
    "EarlyFraudWarningRetrieveParams": (
        "stripe.params.radar._early_fraud_warning_retrieve_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParams": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsAuthorizationDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsCardDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsCardholderDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsMerchantDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsNetworkDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsTokenDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsVerificationDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParams": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsClientDeviceMetadataDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsClientDeviceMetadataDetailsData": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsCustomerDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsMoneyMovementDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsMoneyMovementDetailsCard": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetailsBillingDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetailsBillingDetailsAddress": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsShippingDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsShippingDetailsAddress": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "ValueListCreateParams": (
        "stripe.params.radar._value_list_create_params",
        False,
    ),
    "ValueListDeleteParams": (
        "stripe.params.radar._value_list_delete_params",
        False,
    ),
    "ValueListItemCreateParams": (
        "stripe.params.radar._value_list_item_create_params",
        False,
    ),
    "ValueListItemDeleteParams": (
        "stripe.params.radar._value_list_item_delete_params",
        False,
    ),
    "ValueListItemListParams": (
        "stripe.params.radar._value_list_item_list_params",
        False,
    ),
    "ValueListItemListParamsCreated": (
        "stripe.params.radar._value_list_item_list_params",
        False,
    ),
    "ValueListItemRetrieveParams": (
        "stripe.params.radar._value_list_item_retrieve_params",
        False,
    ),
    "ValueListListParams": (
        "stripe.params.radar._value_list_list_params",
        False,
    ),
    "ValueListListParamsCreated": (
        "stripe.params.radar._value_list_list_params",
        False,
    ),
    "ValueListModifyParams": (
        "stripe.params.radar._value_list_modify_params",
        False,
    ),
    "ValueListRetrieveParams": (
        "stripe.params.radar._value_list_retrieve_params",
        False,
    ),
    "ValueListUpdateParams": (
        "stripe.params.radar._value_list_update_params",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()
