# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing_extensions import NotRequired, TypedDict


class ApprovalRequestListParams(TypedDict):
    limit: NotRequired[int]
    """
    Maximum number of results to return.
    """
