# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing_extensions import TypedDict


class AgreementCreateParams(TypedDict):
    orchestrator: str
    """
    The Network ID of the orchestrator to create an agreement with.
    """
