# -*- coding: utf-8 -*-
# File copied from our code generator; changes here will be overwritten.
# -*- coding: utf-8 -*-

from typing_extensions import TYPE_CHECKING
from stripe.v2.core._event import (
    EventNotification as EventNotification,
    RelatedObject as RelatedObject,
    Reason as Reason,
    ReasonRequest as ReasonRequest,
)

# The beginning of the section generated from our OpenAPI spec
from importlib import import_module

if TYPE_CHECKING:
    from stripe.v2.core import (
        accounts as accounts,
        health as health,
        vault as vault,
    )
    from stripe.v2.core._account import Account as Account
    from stripe.v2.core._account_evaluation import (
        AccountEvaluation as AccountEvaluation,
    )
    from stripe.v2.core._account_evaluation_service import (
        AccountEvaluationService as AccountEvaluationService,
    )
    from stripe.v2.core._account_link import AccountLink as AccountLink
    from stripe.v2.core._account_link_service import (
        AccountLinkService as AccountLinkService,
    )
    from stripe.v2.core._account_person import AccountPerson as AccountPerson
    from stripe.v2.core._account_person_token import (
        AccountPersonToken as AccountPersonToken,
    )
    from stripe.v2.core._account_service import (
        AccountService as AccountService,
    )
    from stripe.v2.core._account_token import AccountToken as AccountToken
    from stripe.v2.core._account_token_service import (
        AccountTokenService as AccountTokenService,
    )
    from stripe.v2.core._approval_request import (
        ApprovalRequest as ApprovalRequest,
    )
    from stripe.v2.core._approval_request_service import (
        ApprovalRequestService as ApprovalRequestService,
    )
    from stripe.v2.core._batch_job import BatchJob as BatchJob
    from stripe.v2.core._batch_job_service import (
        BatchJobService as BatchJobService,
    )
    from stripe.v2.core._claimable_sandbox import (
        ClaimableSandbox as ClaimableSandbox,
    )
    from stripe.v2.core._claimable_sandbox_service import (
        ClaimableSandboxService as ClaimableSandboxService,
    )
    from stripe.v2.core._connection_session import (
        ConnectionSession as ConnectionSession,
    )
    from stripe.v2.core._connection_session_service import (
        ConnectionSessionService as ConnectionSessionService,
    )
    from stripe.v2.core._event import Event as Event
    from stripe.v2.core._event_destination import (
        EventDestination as EventDestination,
    )
    from stripe.v2.core._event_destination_service import (
        EventDestinationService as EventDestinationService,
    )
    from stripe.v2.core._event_service import EventService as EventService
    from stripe.v2.core._fee_batch import FeeBatch as FeeBatch
    from stripe.v2.core._fee_batch_service import (
        FeeBatchService as FeeBatchService,
    )
    from stripe.v2.core._fee_entry import FeeEntry as FeeEntry
    from stripe.v2.core._fee_entry_service import (
        FeeEntryService as FeeEntryService,
    )
    from stripe.v2.core._health_service import HealthService as HealthService
    from stripe.v2.core._vault_service import VaultService as VaultService

# name -> (import_target, is_submodule)
_import_map = {
    "accounts": ("stripe.v2.core.accounts", True),
    "health": ("stripe.v2.core.health", True),
    "vault": ("stripe.v2.core.vault", True),
    "Account": ("stripe.v2.core._account", False),
    "AccountEvaluation": ("stripe.v2.core._account_evaluation", False),
    "AccountEvaluationService": (
        "stripe.v2.core._account_evaluation_service",
        False,
    ),
    "AccountLink": ("stripe.v2.core._account_link", False),
    "AccountLinkService": ("stripe.v2.core._account_link_service", False),
    "AccountPerson": ("stripe.v2.core._account_person", False),
    "AccountPersonToken": ("stripe.v2.core._account_person_token", False),
    "AccountService": ("stripe.v2.core._account_service", False),
    "AccountToken": ("stripe.v2.core._account_token", False),
    "AccountTokenService": ("stripe.v2.core._account_token_service", False),
    "ApprovalRequest": ("stripe.v2.core._approval_request", False),
    "ApprovalRequestService": (
        "stripe.v2.core._approval_request_service",
        False,
    ),
    "BatchJob": ("stripe.v2.core._batch_job", False),
    "BatchJobService": ("stripe.v2.core._batch_job_service", False),
    "ClaimableSandbox": ("stripe.v2.core._claimable_sandbox", False),
    "ClaimableSandboxService": (
        "stripe.v2.core._claimable_sandbox_service",
        False,
    ),
    "ConnectionSession": ("stripe.v2.core._connection_session", False),
    "ConnectionSessionService": (
        "stripe.v2.core._connection_session_service",
        False,
    ),
    "Event": ("stripe.v2.core._event", False),
    "EventDestination": ("stripe.v2.core._event_destination", False),
    "EventDestinationService": (
        "stripe.v2.core._event_destination_service",
        False,
    ),
    "EventService": ("stripe.v2.core._event_service", False),
    "FeeBatch": ("stripe.v2.core._fee_batch", False),
    "FeeBatchService": ("stripe.v2.core._fee_batch_service", False),
    "FeeEntry": ("stripe.v2.core._fee_entry", False),
    "FeeEntryService": ("stripe.v2.core._fee_entry_service", False),
    "HealthService": ("stripe.v2.core._health_service", False),
    "VaultService": ("stripe.v2.core._vault_service", False),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()

# The end of the section generated from our OpenAPI spec
