# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing_extensions import NotRequired, TypedDict


class ApprovalRequestSubmitParams(TypedDict):
    reason: NotRequired[str]
    """
    The reason for submitting the approval request.
    """
