# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.v2.core import (
        accounts as accounts,
        health as health,
        vault as vault,
    )
    from stripe.params.v2.core._account_close_params import (
        AccountCloseParams as AccountCloseParams,
    )
    from stripe.params.v2.core._account_create_params import (
        AccountCreateParams as AccountCreateParams,
        AccountCreateParamsConfiguration as AccountCreateParamsConfiguration,
        AccountCreateParamsConfigurationCardCreator as AccountCreateParamsConfigurationCardCreator,
        AccountCreateParamsConfigurationCardCreatorCapabilities as AccountCreateParamsConfigurationCardCreatorCapabilities,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercial as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercial,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtections as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtections,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtectionsPspMigration as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtectionsPspMigration,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtections as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtections,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtectionsPspMigration as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtectionsPspMigration,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtections as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtections,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtectionsPspMigration as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtectionsPspMigration,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtections as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtections,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtectionsPspMigration as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtectionsPspMigration,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtections as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtections,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtectionsPspMigration as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtectionsPspMigration,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThird as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThird,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtections as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtections,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtectionsPspMigration as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtectionsPspMigration,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLead as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLead,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtections as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtections,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtectionsPspMigration as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtectionsPspMigration,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripe as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripe,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtections as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtections,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtectionsPspMigration as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtectionsPspMigration,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtections as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtections,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtectionsPspMigration as AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtectionsPspMigration,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumer as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumer,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCeltic as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCeltic,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtections as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtections,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtectionsPspMigration as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtectionsPspMigration,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBank as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBank,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtections as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtections,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtectionsPspMigration as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtectionsPspMigration,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLead as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLead,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtections as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtections,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtectionsPspMigration as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtectionsPspMigration,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCard as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCard,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtections as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtections,
        AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtectionsPspMigration as AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtectionsPspMigration,
        AccountCreateParamsConfigurationCustomer as AccountCreateParamsConfigurationCustomer,
        AccountCreateParamsConfigurationCustomerAutomaticIndirectTax as AccountCreateParamsConfigurationCustomerAutomaticIndirectTax,
        AccountCreateParamsConfigurationCustomerBilling as AccountCreateParamsConfigurationCustomerBilling,
        AccountCreateParamsConfigurationCustomerBillingInvoice as AccountCreateParamsConfigurationCustomerBillingInvoice,
        AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField as AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField,
        AccountCreateParamsConfigurationCustomerBillingInvoiceRendering as AccountCreateParamsConfigurationCustomerBillingInvoiceRendering,
        AccountCreateParamsConfigurationCustomerCapabilities as AccountCreateParamsConfigurationCustomerCapabilities,
        AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax as AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax,
        AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtections as AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtections,
        AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtectionsPspMigration as AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtectionsPspMigration,
        AccountCreateParamsConfigurationCustomerShipping as AccountCreateParamsConfigurationCustomerShipping,
        AccountCreateParamsConfigurationCustomerShippingAddress as AccountCreateParamsConfigurationCustomerShippingAddress,
        AccountCreateParamsConfigurationMerchant as AccountCreateParamsConfigurationMerchant,
        AccountCreateParamsConfigurationMerchantBacsDebitPayments as AccountCreateParamsConfigurationMerchantBacsDebitPayments,
        AccountCreateParamsConfigurationMerchantBranding as AccountCreateParamsConfigurationMerchantBranding,
        AccountCreateParamsConfigurationMerchantCapabilities as AccountCreateParamsConfigurationMerchantCapabilities,
        AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesCardPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesCardPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesCardPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesCardPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments as AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments as AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments as AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments as AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments as AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments as AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments,
        AccountCreateParamsConfigurationMerchantCapabilitiesP24PaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesP24PaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesP24PaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesP24PaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments as AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments as AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesZipPaymentsProtections as AccountCreateParamsConfigurationMerchantCapabilitiesZipPaymentsProtections,
        AccountCreateParamsConfigurationMerchantCapabilitiesZipPaymentsProtectionsPspMigration as AccountCreateParamsConfigurationMerchantCapabilitiesZipPaymentsProtectionsPspMigration,
        AccountCreateParamsConfigurationMerchantCardPayments as AccountCreateParamsConfigurationMerchantCardPayments,
        AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn as AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn,
        AccountCreateParamsConfigurationMerchantKonbiniPayments as AccountCreateParamsConfigurationMerchantKonbiniPayments,
        AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupport as AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupport,
        AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupportHours as AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupportHours,
        AccountCreateParamsConfigurationMerchantScriptStatementDescriptor as AccountCreateParamsConfigurationMerchantScriptStatementDescriptor,
        AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKana as AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKana,
        AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKanji as AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKanji,
        AccountCreateParamsConfigurationMerchantSmartDisputes as AccountCreateParamsConfigurationMerchantSmartDisputes,
        AccountCreateParamsConfigurationMerchantSmartDisputesAutoRespond as AccountCreateParamsConfigurationMerchantSmartDisputesAutoRespond,
        AccountCreateParamsConfigurationMerchantStatementDescriptor as AccountCreateParamsConfigurationMerchantStatementDescriptor,
        AccountCreateParamsConfigurationMerchantSupport as AccountCreateParamsConfigurationMerchantSupport,
        AccountCreateParamsConfigurationMerchantSupportAddress as AccountCreateParamsConfigurationMerchantSupportAddress,
        AccountCreateParamsConfigurationMoneyManager as AccountCreateParamsConfigurationMoneyManager,
        AccountCreateParamsConfigurationMoneyManagerCapabilities as AccountCreateParamsConfigurationMoneyManagerCapabilities,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorage as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorage,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInbound as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInbound,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAud as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAud,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCad as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCad,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEur as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEur,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbp as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbp,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsd as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsd,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdc as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdc,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutbound as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutbound,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAud as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAud,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCad as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCad,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEur as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEur,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbp as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbp,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsd as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsd,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdc as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdc,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorage as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorage,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInbound as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInbound,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsd as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsd,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdc as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdc,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutbound as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutbound,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsd as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsd,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdc as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdc,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfers as AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfers,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccounts as AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccounts,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPayments as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPayments,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccounts as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccounts,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCards as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCards,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWallets as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWallets,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccounts as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccounts,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecks as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecks,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfers as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfers,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccounts as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccounts,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWallets as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWallets,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccounts as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccounts,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCredits as AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCredits,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccounts as AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccounts,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWallets as AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWallets,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebits as AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebits,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccounts as AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccounts,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtections as AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtections,
        AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtectionsPspMigration as AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtectionsPspMigration,
        AccountCreateParamsConfigurationMoneyManagerRegulatedActivity as AccountCreateParamsConfigurationMoneyManagerRegulatedActivity,
        AccountCreateParamsConfigurationRecipient as AccountCreateParamsConfigurationRecipient,
        AccountCreateParamsConfigurationRecipientCapabilities as AccountCreateParamsConfigurationRecipientCapabilities,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccounts as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccounts,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAch as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAch,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtections as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecs as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecs,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtections as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEft as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEft,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtections as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwire as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwire,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtections as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFps as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFps,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtections as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstant as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstant,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtections as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocal as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocal,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtections as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNpp as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNpp,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtections as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtp as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtp,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtections as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCredit as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCredit,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtections as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstant as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstant,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtections as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwift as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwift,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtections as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWire as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWire,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtections as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesCards as AccountCreateParamsConfigurationRecipientCapabilitiesCards,
        AccountCreateParamsConfigurationRecipientCapabilitiesCardsProtections as AccountCreateParamsConfigurationRecipientCapabilitiesCardsProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesCardsProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesCardsProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWallets as AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWallets,
        AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtections as AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecks as AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecks,
        AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecksProtections as AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecksProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecksProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecksProtectionsPspMigration,
        AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance as AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance,
        AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers as AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers,
        AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtections as AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtections,
        AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtectionsPspMigration as AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtectionsPspMigration,
        AccountCreateParamsDefaults as AccountCreateParamsDefaults,
        AccountCreateParamsDefaultsProfile as AccountCreateParamsDefaultsProfile,
        AccountCreateParamsDefaultsResponsibilities as AccountCreateParamsDefaultsResponsibilities,
        AccountCreateParamsIdentity as AccountCreateParamsIdentity,
        AccountCreateParamsIdentityAttestations as AccountCreateParamsIdentityAttestations,
        AccountCreateParamsIdentityAttestationsDirectorshipDeclaration as AccountCreateParamsIdentityAttestationsDirectorshipDeclaration,
        AccountCreateParamsIdentityAttestationsOwnershipDeclaration as AccountCreateParamsIdentityAttestationsOwnershipDeclaration,
        AccountCreateParamsIdentityAttestationsPersonsProvided as AccountCreateParamsIdentityAttestationsPersonsProvided,
        AccountCreateParamsIdentityAttestationsRepresentativeDeclaration as AccountCreateParamsIdentityAttestationsRepresentativeDeclaration,
        AccountCreateParamsIdentityAttestationsTermsOfService as AccountCreateParamsIdentityAttestationsTermsOfService,
        AccountCreateParamsIdentityAttestationsTermsOfServiceAccount as AccountCreateParamsIdentityAttestationsTermsOfServiceAccount,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreator as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreator,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThird as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThird,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdApplePay as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdApplePay,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardFinancingDisclosures,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumer as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumer,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerAccountHolder as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerAccountHolder,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCeltic as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCeltic,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticApplePay as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticApplePay,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardFinancingDisclosures,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBank as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBank,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardFinancingDisclosures,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerGlobalAccountHolder as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerGlobalAccountHolder,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLead as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLead,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardFinancingDisclosures,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCard as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCard,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardBankTerms as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardBankTerms,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardFinancingDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardFinancingDisclosures,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardPlatform as AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardPlatform,
        AccountCreateParamsIdentityAttestationsTermsOfServiceConsumerMoneyManager as AccountCreateParamsIdentityAttestationsTermsOfServiceConsumerMoneyManager,
        AccountCreateParamsIdentityAttestationsTermsOfServiceConsumerPrivacyDisclosures as AccountCreateParamsIdentityAttestationsTermsOfServiceConsumerPrivacyDisclosures,
        AccountCreateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager as AccountCreateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager,
        AccountCreateParamsIdentityAttestationsTermsOfServiceMoneyManager as AccountCreateParamsIdentityAttestationsTermsOfServiceMoneyManager,
        AccountCreateParamsIdentityBusinessDetails as AccountCreateParamsIdentityBusinessDetails,
        AccountCreateParamsIdentityBusinessDetailsAddress as AccountCreateParamsIdentityBusinessDetailsAddress,
        AccountCreateParamsIdentityBusinessDetailsAnnualRevenue as AccountCreateParamsIdentityBusinessDetailsAnnualRevenue,
        AccountCreateParamsIdentityBusinessDetailsDocuments as AccountCreateParamsIdentityBusinessDetailsDocuments,
        AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack as AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner,
        AccountCreateParamsIdentityBusinessDetailsIdNumber as AccountCreateParamsIdentityBusinessDetailsIdNumber,
        AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue as AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue,
        AccountCreateParamsIdentityBusinessDetailsRegistrationDate as AccountCreateParamsIdentityBusinessDetailsRegistrationDate,
        AccountCreateParamsIdentityBusinessDetailsScriptAddresses as AccountCreateParamsIdentityBusinessDetailsScriptAddresses,
        AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana as AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana,
        AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji as AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji,
        AccountCreateParamsIdentityBusinessDetailsScriptNames as AccountCreateParamsIdentityBusinessDetailsScriptNames,
        AccountCreateParamsIdentityBusinessDetailsScriptNamesKana as AccountCreateParamsIdentityBusinessDetailsScriptNamesKana,
        AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji as AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji,
        AccountCreateParamsIdentityIndividual as AccountCreateParamsIdentityIndividual,
        AccountCreateParamsIdentityIndividualAdditionalAddress as AccountCreateParamsIdentityIndividualAdditionalAddress,
        AccountCreateParamsIdentityIndividualAdditionalName as AccountCreateParamsIdentityIndividualAdditionalName,
        AccountCreateParamsIdentityIndividualAddress as AccountCreateParamsIdentityIndividualAddress,
        AccountCreateParamsIdentityIndividualDateOfBirth as AccountCreateParamsIdentityIndividualDateOfBirth,
        AccountCreateParamsIdentityIndividualDocuments as AccountCreateParamsIdentityIndividualDocuments,
        AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization as AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization,
        AccountCreateParamsIdentityIndividualDocumentsPassport as AccountCreateParamsIdentityIndividualDocumentsPassport,
        AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification as AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification,
        AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack as AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack,
        AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification as AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification,
        AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack as AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack,
        AccountCreateParamsIdentityIndividualDocumentsVisa as AccountCreateParamsIdentityIndividualDocumentsVisa,
        AccountCreateParamsIdentityIndividualIdNumber as AccountCreateParamsIdentityIndividualIdNumber,
        AccountCreateParamsIdentityIndividualRelationship as AccountCreateParamsIdentityIndividualRelationship,
        AccountCreateParamsIdentityIndividualScriptAddresses as AccountCreateParamsIdentityIndividualScriptAddresses,
        AccountCreateParamsIdentityIndividualScriptAddressesKana as AccountCreateParamsIdentityIndividualScriptAddressesKana,
        AccountCreateParamsIdentityIndividualScriptAddressesKanji as AccountCreateParamsIdentityIndividualScriptAddressesKanji,
        AccountCreateParamsIdentityIndividualScriptNames as AccountCreateParamsIdentityIndividualScriptNames,
        AccountCreateParamsIdentityIndividualScriptNamesKana as AccountCreateParamsIdentityIndividualScriptNamesKana,
        AccountCreateParamsIdentityIndividualScriptNamesKanji as AccountCreateParamsIdentityIndividualScriptNamesKanji,
    )
    from stripe.params.v2.core._account_evaluation_create_params import (
        AccountEvaluationCreateParams as AccountEvaluationCreateParams,
        AccountEvaluationCreateParamsAccountData as AccountEvaluationCreateParamsAccountData,
        AccountEvaluationCreateParamsAccountDataDefaults as AccountEvaluationCreateParamsAccountDataDefaults,
        AccountEvaluationCreateParamsAccountDataDefaultsProfile as AccountEvaluationCreateParamsAccountDataDefaultsProfile,
        AccountEvaluationCreateParamsAccountDataIdentity as AccountEvaluationCreateParamsAccountDataIdentity,
        AccountEvaluationCreateParamsAccountDataIdentityBusinessDetails as AccountEvaluationCreateParamsAccountDataIdentityBusinessDetails,
    )
    from stripe.params.v2.core._account_link_create_params import (
        AccountLinkCreateParams as AccountLinkCreateParams,
        AccountLinkCreateParamsUseCase as AccountLinkCreateParamsUseCase,
        AccountLinkCreateParamsUseCaseAccountOnboarding as AccountLinkCreateParamsUseCaseAccountOnboarding,
        AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions as AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions,
        AccountLinkCreateParamsUseCaseAccountUpdate as AccountLinkCreateParamsUseCaseAccountUpdate,
        AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions as AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions,
        AccountLinkCreateParamsUseCaseRecipientOnboarding as AccountLinkCreateParamsUseCaseRecipientOnboarding,
        AccountLinkCreateParamsUseCaseRecipientOnboardingCollectionOptions as AccountLinkCreateParamsUseCaseRecipientOnboardingCollectionOptions,
        AccountLinkCreateParamsUseCaseRecipientUpdate as AccountLinkCreateParamsUseCaseRecipientUpdate,
        AccountLinkCreateParamsUseCaseRecipientUpdateCollectionOptions as AccountLinkCreateParamsUseCaseRecipientUpdateCollectionOptions,
    )
    from stripe.params.v2.core._account_list_params import (
        AccountListParams as AccountListParams,
    )
    from stripe.params.v2.core._account_retrieve_params import (
        AccountRetrieveParams as AccountRetrieveParams,
    )
    from stripe.params.v2.core._account_token_create_params import (
        AccountTokenCreateParams as AccountTokenCreateParams,
        AccountTokenCreateParamsIdentity as AccountTokenCreateParamsIdentity,
        AccountTokenCreateParamsIdentityAttestations as AccountTokenCreateParamsIdentityAttestations,
        AccountTokenCreateParamsIdentityAttestationsDirectorshipDeclaration as AccountTokenCreateParamsIdentityAttestationsDirectorshipDeclaration,
        AccountTokenCreateParamsIdentityAttestationsOwnershipDeclaration as AccountTokenCreateParamsIdentityAttestationsOwnershipDeclaration,
        AccountTokenCreateParamsIdentityAttestationsPersonsProvided as AccountTokenCreateParamsIdentityAttestationsPersonsProvided,
        AccountTokenCreateParamsIdentityAttestationsRepresentativeDeclaration as AccountTokenCreateParamsIdentityAttestationsRepresentativeDeclaration,
        AccountTokenCreateParamsIdentityAttestationsTermsOfService as AccountTokenCreateParamsIdentityAttestationsTermsOfService,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceAccount as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceAccount,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreator as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreator,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceMoneyManager as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceMoneyManager,
        AccountTokenCreateParamsIdentityBusinessDetails as AccountTokenCreateParamsIdentityBusinessDetails,
        AccountTokenCreateParamsIdentityBusinessDetailsAddress as AccountTokenCreateParamsIdentityBusinessDetailsAddress,
        AccountTokenCreateParamsIdentityBusinessDetailsAnnualRevenue as AccountTokenCreateParamsIdentityBusinessDetailsAnnualRevenue,
        AccountTokenCreateParamsIdentityBusinessDetailsDocuments as AccountTokenCreateParamsIdentityBusinessDetailsDocuments,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner,
        AccountTokenCreateParamsIdentityBusinessDetailsIdNumber as AccountTokenCreateParamsIdentityBusinessDetailsIdNumber,
        AccountTokenCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue as AccountTokenCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue,
        AccountTokenCreateParamsIdentityBusinessDetailsRegistrationDate as AccountTokenCreateParamsIdentityBusinessDetailsRegistrationDate,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptAddresses as AccountTokenCreateParamsIdentityBusinessDetailsScriptAddresses,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKana as AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKana,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKanji as AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKanji,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptNames as AccountTokenCreateParamsIdentityBusinessDetailsScriptNames,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKana as AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKana,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKanji as AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKanji,
        AccountTokenCreateParamsIdentityIndividual as AccountTokenCreateParamsIdentityIndividual,
        AccountTokenCreateParamsIdentityIndividualAdditionalAddress as AccountTokenCreateParamsIdentityIndividualAdditionalAddress,
        AccountTokenCreateParamsIdentityIndividualAdditionalName as AccountTokenCreateParamsIdentityIndividualAdditionalName,
        AccountTokenCreateParamsIdentityIndividualAddress as AccountTokenCreateParamsIdentityIndividualAddress,
        AccountTokenCreateParamsIdentityIndividualDateOfBirth as AccountTokenCreateParamsIdentityIndividualDateOfBirth,
        AccountTokenCreateParamsIdentityIndividualDocuments as AccountTokenCreateParamsIdentityIndividualDocuments,
        AccountTokenCreateParamsIdentityIndividualDocumentsCompanyAuthorization as AccountTokenCreateParamsIdentityIndividualDocumentsCompanyAuthorization,
        AccountTokenCreateParamsIdentityIndividualDocumentsPassport as AccountTokenCreateParamsIdentityIndividualDocumentsPassport,
        AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerification as AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerification,
        AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack as AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack,
        AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerification as AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerification,
        AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack as AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack,
        AccountTokenCreateParamsIdentityIndividualDocumentsVisa as AccountTokenCreateParamsIdentityIndividualDocumentsVisa,
        AccountTokenCreateParamsIdentityIndividualIdNumber as AccountTokenCreateParamsIdentityIndividualIdNumber,
        AccountTokenCreateParamsIdentityIndividualRelationship as AccountTokenCreateParamsIdentityIndividualRelationship,
        AccountTokenCreateParamsIdentityIndividualScriptAddresses as AccountTokenCreateParamsIdentityIndividualScriptAddresses,
        AccountTokenCreateParamsIdentityIndividualScriptAddressesKana as AccountTokenCreateParamsIdentityIndividualScriptAddressesKana,
        AccountTokenCreateParamsIdentityIndividualScriptAddressesKanji as AccountTokenCreateParamsIdentityIndividualScriptAddressesKanji,
        AccountTokenCreateParamsIdentityIndividualScriptNames as AccountTokenCreateParamsIdentityIndividualScriptNames,
        AccountTokenCreateParamsIdentityIndividualScriptNamesKana as AccountTokenCreateParamsIdentityIndividualScriptNamesKana,
        AccountTokenCreateParamsIdentityIndividualScriptNamesKanji as AccountTokenCreateParamsIdentityIndividualScriptNamesKanji,
    )
    from stripe.params.v2.core._account_token_retrieve_params import (
        AccountTokenRetrieveParams as AccountTokenRetrieveParams,
    )
    from stripe.params.v2.core._account_update_params import (
        AccountUpdateParams as AccountUpdateParams,
        AccountUpdateParamsConfiguration as AccountUpdateParamsConfiguration,
        AccountUpdateParamsConfigurationCardCreator as AccountUpdateParamsConfigurationCardCreator,
        AccountUpdateParamsConfigurationCardCreatorCapabilities as AccountUpdateParamsConfigurationCardCreatorCapabilities,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercial as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercial,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtections as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtections,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtectionsPspMigration as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtectionsPspMigration,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtections as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtections,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtectionsPspMigration as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtectionsPspMigration,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtections as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtections,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtectionsPspMigration as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtectionsPspMigration,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtections as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtections,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtectionsPspMigration as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtectionsPspMigration,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtections as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtections,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtectionsPspMigration as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtectionsPspMigration,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThird as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThird,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtections as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtections,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtectionsPspMigration as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtectionsPspMigration,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLead as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLead,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtections as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtections,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtectionsPspMigration as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtectionsPspMigration,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripe as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripe,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtections as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtections,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtectionsPspMigration as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtectionsPspMigration,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtections as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtections,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtectionsPspMigration as AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtectionsPspMigration,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumer as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumer,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCeltic as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCeltic,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtections as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtections,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtectionsPspMigration as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtectionsPspMigration,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBank as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBank,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtections as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtections,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtectionsPspMigration as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtectionsPspMigration,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLead as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLead,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtections as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtections,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtectionsPspMigration as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtectionsPspMigration,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCard as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCard,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtections as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtections,
        AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtectionsPspMigration as AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtectionsPspMigration,
        AccountUpdateParamsConfigurationCustomer as AccountUpdateParamsConfigurationCustomer,
        AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax as AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax,
        AccountUpdateParamsConfigurationCustomerBilling as AccountUpdateParamsConfigurationCustomerBilling,
        AccountUpdateParamsConfigurationCustomerBillingInvoice as AccountUpdateParamsConfigurationCustomerBillingInvoice,
        AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField as AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField,
        AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering as AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering,
        AccountUpdateParamsConfigurationCustomerCapabilities as AccountUpdateParamsConfigurationCustomerCapabilities,
        AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax as AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax,
        AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtections as AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtections,
        AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtectionsPspMigration as AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtectionsPspMigration,
        AccountUpdateParamsConfigurationCustomerShipping as AccountUpdateParamsConfigurationCustomerShipping,
        AccountUpdateParamsConfigurationCustomerShippingAddress as AccountUpdateParamsConfigurationCustomerShippingAddress,
        AccountUpdateParamsConfigurationMerchant as AccountUpdateParamsConfigurationMerchant,
        AccountUpdateParamsConfigurationMerchantBacsDebitPayments as AccountUpdateParamsConfigurationMerchantBacsDebitPayments,
        AccountUpdateParamsConfigurationMerchantBranding as AccountUpdateParamsConfigurationMerchantBranding,
        AccountUpdateParamsConfigurationMerchantCapabilities as AccountUpdateParamsConfigurationMerchantCapabilities,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCardPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesCardPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCardPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesCardPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments as AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesP24PaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesP24PaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesP24PaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesP24PaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesZipPaymentsProtections as AccountUpdateParamsConfigurationMerchantCapabilitiesZipPaymentsProtections,
        AccountUpdateParamsConfigurationMerchantCapabilitiesZipPaymentsProtectionsPspMigration as AccountUpdateParamsConfigurationMerchantCapabilitiesZipPaymentsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMerchantCardPayments as AccountUpdateParamsConfigurationMerchantCardPayments,
        AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn as AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn,
        AccountUpdateParamsConfigurationMerchantKonbiniPayments as AccountUpdateParamsConfigurationMerchantKonbiniPayments,
        AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupport as AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupport,
        AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupportHours as AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupportHours,
        AccountUpdateParamsConfigurationMerchantScriptStatementDescriptor as AccountUpdateParamsConfigurationMerchantScriptStatementDescriptor,
        AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKana as AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKana,
        AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKanji as AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKanji,
        AccountUpdateParamsConfigurationMerchantSmartDisputes as AccountUpdateParamsConfigurationMerchantSmartDisputes,
        AccountUpdateParamsConfigurationMerchantSmartDisputesAutoRespond as AccountUpdateParamsConfigurationMerchantSmartDisputesAutoRespond,
        AccountUpdateParamsConfigurationMerchantStatementDescriptor as AccountUpdateParamsConfigurationMerchantStatementDescriptor,
        AccountUpdateParamsConfigurationMerchantSupport as AccountUpdateParamsConfigurationMerchantSupport,
        AccountUpdateParamsConfigurationMerchantSupportAddress as AccountUpdateParamsConfigurationMerchantSupportAddress,
        AccountUpdateParamsConfigurationMoneyManager as AccountUpdateParamsConfigurationMoneyManager,
        AccountUpdateParamsConfigurationMoneyManagerCapabilities as AccountUpdateParamsConfigurationMoneyManagerCapabilities,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorage as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorage,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInbound as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInbound,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAud as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAud,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCad as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCad,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEur as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEur,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbp as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbp,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsd as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsd,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdc as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdc,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutbound as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutbound,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAud as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAud,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCad as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCad,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEur as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEur,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbp as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbp,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsd as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsd,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdc as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdc,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorage as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorage,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInbound as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInbound,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsd as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsd,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdc as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdc,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutbound as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutbound,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsd as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsd,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdc as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdc,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesInboundTransfers as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesInboundTransfers,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccounts as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccounts,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPayments as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPayments,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccounts as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccounts,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCards as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCards,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWallets as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWallets,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccounts as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccounts,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecks as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecks,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfers as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfers,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccounts as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccounts,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWallets as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWallets,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccounts as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccounts,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCredits as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCredits,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccounts as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccounts,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWallets as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWallets,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedDebits as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedDebits,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccounts as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccounts,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtections as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtections,
        AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtectionsPspMigration as AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtectionsPspMigration,
        AccountUpdateParamsConfigurationMoneyManagerRegulatedActivity as AccountUpdateParamsConfigurationMoneyManagerRegulatedActivity,
        AccountUpdateParamsConfigurationRecipient as AccountUpdateParamsConfigurationRecipient,
        AccountUpdateParamsConfigurationRecipientCapabilities as AccountUpdateParamsConfigurationRecipientCapabilities,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccounts as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccounts,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsAch as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsAch,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsBecs as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsBecs,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsEft as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsEft,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFedwire as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFedwire,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFps as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFps,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsInstant as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsInstant,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocal as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocal,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsNpp as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsNpp,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsRtp as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsRtp,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCredit as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCredit,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstant as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstant,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSwift as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSwift,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWire as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWire,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesCards as AccountUpdateParamsConfigurationRecipientCapabilitiesCards,
        AccountUpdateParamsConfigurationRecipientCapabilitiesCardsProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesCardsProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesCardsProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesCardsProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWallets as AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWallets,
        AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesPaperChecks as AccountUpdateParamsConfigurationRecipientCapabilitiesPaperChecks,
        AccountUpdateParamsConfigurationRecipientCapabilitiesPaperChecksProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesPaperChecksProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesPaperChecksProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesPaperChecksProtectionsPspMigration,
        AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance as AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance,
        AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers as AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers,
        AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtections as AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtections,
        AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtectionsPspMigration as AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtectionsPspMigration,
        AccountUpdateParamsDefaults as AccountUpdateParamsDefaults,
        AccountUpdateParamsDefaultsProfile as AccountUpdateParamsDefaultsProfile,
        AccountUpdateParamsDefaultsResponsibilities as AccountUpdateParamsDefaultsResponsibilities,
        AccountUpdateParamsIdentity as AccountUpdateParamsIdentity,
        AccountUpdateParamsIdentityAttestations as AccountUpdateParamsIdentityAttestations,
        AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration as AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration,
        AccountUpdateParamsIdentityAttestationsOwnershipDeclaration as AccountUpdateParamsIdentityAttestationsOwnershipDeclaration,
        AccountUpdateParamsIdentityAttestationsPersonsProvided as AccountUpdateParamsIdentityAttestationsPersonsProvided,
        AccountUpdateParamsIdentityAttestationsRepresentativeDeclaration as AccountUpdateParamsIdentityAttestationsRepresentativeDeclaration,
        AccountUpdateParamsIdentityAttestationsTermsOfService as AccountUpdateParamsIdentityAttestationsTermsOfService,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount as AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreator as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreator,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThird as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThird,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdApplePay as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdApplePay,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumer as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumer,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerAccountHolder as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerAccountHolder,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCeltic as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCeltic,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticApplePay as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticApplePay,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardFinancingDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardFinancingDisclosures,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBank as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBank,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardFinancingDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardFinancingDisclosures,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerGlobalAccountHolder as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerGlobalAccountHolder,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLead as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLead,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadApplePay as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadApplePay,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardFinancingDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardFinancingDisclosures,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCard as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCard,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardBankTerms as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardBankTerms,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardFinancingDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardFinancingDisclosures,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardPlatform as AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardPlatform,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceConsumerMoneyManager as AccountUpdateParamsIdentityAttestationsTermsOfServiceConsumerMoneyManager,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceConsumerPrivacyDisclosures as AccountUpdateParamsIdentityAttestationsTermsOfServiceConsumerPrivacyDisclosures,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager as AccountUpdateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceMoneyManager as AccountUpdateParamsIdentityAttestationsTermsOfServiceMoneyManager,
        AccountUpdateParamsIdentityBusinessDetails as AccountUpdateParamsIdentityBusinessDetails,
        AccountUpdateParamsIdentityBusinessDetailsAddress as AccountUpdateParamsIdentityBusinessDetailsAddress,
        AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue as AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue,
        AccountUpdateParamsIdentityBusinessDetailsDocuments as AccountUpdateParamsIdentityBusinessDetailsDocuments,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack as AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner,
        AccountUpdateParamsIdentityBusinessDetailsIdNumber as AccountUpdateParamsIdentityBusinessDetailsIdNumber,
        AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue as AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue,
        AccountUpdateParamsIdentityBusinessDetailsRegistrationDate as AccountUpdateParamsIdentityBusinessDetailsRegistrationDate,
        AccountUpdateParamsIdentityBusinessDetailsScriptAddresses as AccountUpdateParamsIdentityBusinessDetailsScriptAddresses,
        AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana as AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana,
        AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji as AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji,
        AccountUpdateParamsIdentityBusinessDetailsScriptNames as AccountUpdateParamsIdentityBusinessDetailsScriptNames,
        AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana as AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana,
        AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji as AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji,
        AccountUpdateParamsIdentityIndividual as AccountUpdateParamsIdentityIndividual,
        AccountUpdateParamsIdentityIndividualAdditionalAddress as AccountUpdateParamsIdentityIndividualAdditionalAddress,
        AccountUpdateParamsIdentityIndividualAdditionalName as AccountUpdateParamsIdentityIndividualAdditionalName,
        AccountUpdateParamsIdentityIndividualAddress as AccountUpdateParamsIdentityIndividualAddress,
        AccountUpdateParamsIdentityIndividualDateOfBirth as AccountUpdateParamsIdentityIndividualDateOfBirth,
        AccountUpdateParamsIdentityIndividualDocuments as AccountUpdateParamsIdentityIndividualDocuments,
        AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization as AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization,
        AccountUpdateParamsIdentityIndividualDocumentsPassport as AccountUpdateParamsIdentityIndividualDocumentsPassport,
        AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification as AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification,
        AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack as AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack,
        AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification as AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification,
        AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack as AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack,
        AccountUpdateParamsIdentityIndividualDocumentsVisa as AccountUpdateParamsIdentityIndividualDocumentsVisa,
        AccountUpdateParamsIdentityIndividualIdNumber as AccountUpdateParamsIdentityIndividualIdNumber,
        AccountUpdateParamsIdentityIndividualRelationship as AccountUpdateParamsIdentityIndividualRelationship,
        AccountUpdateParamsIdentityIndividualScriptAddresses as AccountUpdateParamsIdentityIndividualScriptAddresses,
        AccountUpdateParamsIdentityIndividualScriptAddressesKana as AccountUpdateParamsIdentityIndividualScriptAddressesKana,
        AccountUpdateParamsIdentityIndividualScriptAddressesKanji as AccountUpdateParamsIdentityIndividualScriptAddressesKanji,
        AccountUpdateParamsIdentityIndividualScriptNames as AccountUpdateParamsIdentityIndividualScriptNames,
        AccountUpdateParamsIdentityIndividualScriptNamesKana as AccountUpdateParamsIdentityIndividualScriptNamesKana,
        AccountUpdateParamsIdentityIndividualScriptNamesKanji as AccountUpdateParamsIdentityIndividualScriptNamesKanji,
    )
    from stripe.params.v2.core._approval_request_cancel_params import (
        ApprovalRequestCancelParams as ApprovalRequestCancelParams,
    )
    from stripe.params.v2.core._approval_request_execute_params import (
        ApprovalRequestExecuteParams as ApprovalRequestExecuteParams,
    )
    from stripe.params.v2.core._approval_request_list_params import (
        ApprovalRequestListParams as ApprovalRequestListParams,
    )
    from stripe.params.v2.core._approval_request_retrieve_params import (
        ApprovalRequestRetrieveParams as ApprovalRequestRetrieveParams,
    )
    from stripe.params.v2.core._approval_request_submit_params import (
        ApprovalRequestSubmitParams as ApprovalRequestSubmitParams,
    )
    from stripe.params.v2.core._batch_job_cancel_params import (
        BatchJobCancelParams as BatchJobCancelParams,
    )
    from stripe.params.v2.core._batch_job_create_params import (
        BatchJobCreateParams as BatchJobCreateParams,
        BatchJobCreateParamsEndpoint as BatchJobCreateParamsEndpoint,
        BatchJobCreateParamsNotificationSuppression as BatchJobCreateParamsNotificationSuppression,
    )
    from stripe.params.v2.core._batch_job_retrieve_params import (
        BatchJobRetrieveParams as BatchJobRetrieveParams,
    )
    from stripe.params.v2.core._claimable_sandbox_create_params import (
        ClaimableSandboxCreateParams as ClaimableSandboxCreateParams,
        ClaimableSandboxCreateParamsOnboardingLinkDetails as ClaimableSandboxCreateParamsOnboardingLinkDetails,
        ClaimableSandboxCreateParamsPrefill as ClaimableSandboxCreateParamsPrefill,
    )
    from stripe.params.v2.core._claimable_sandbox_renew_onboarding_link_params import (
        ClaimableSandboxRenewOnboardingLinkParams as ClaimableSandboxRenewOnboardingLinkParams,
        ClaimableSandboxRenewOnboardingLinkParamsOnboardingLinkDetails as ClaimableSandboxRenewOnboardingLinkParamsOnboardingLinkDetails,
    )
    from stripe.params.v2.core._claimable_sandbox_retrieve_params import (
        ClaimableSandboxRetrieveParams as ClaimableSandboxRetrieveParams,
    )
    from stripe.params.v2.core._connection_session_create_params import (
        ConnectionSessionCreateParams as ConnectionSessionCreateParams,
    )
    from stripe.params.v2.core._connection_session_retrieve_params import (
        ConnectionSessionRetrieveParams as ConnectionSessionRetrieveParams,
    )
    from stripe.params.v2.core._event_destination_create_params import (
        EventDestinationCreateParams as EventDestinationCreateParams,
        EventDestinationCreateParamsAmazonEventbridge as EventDestinationCreateParamsAmazonEventbridge,
        EventDestinationCreateParamsAzureEventGrid as EventDestinationCreateParamsAzureEventGrid,
        EventDestinationCreateParamsWebhookEndpoint as EventDestinationCreateParamsWebhookEndpoint,
    )
    from stripe.params.v2.core._event_destination_delete_params import (
        EventDestinationDeleteParams as EventDestinationDeleteParams,
    )
    from stripe.params.v2.core._event_destination_disable_params import (
        EventDestinationDisableParams as EventDestinationDisableParams,
    )
    from stripe.params.v2.core._event_destination_enable_params import (
        EventDestinationEnableParams as EventDestinationEnableParams,
    )
    from stripe.params.v2.core._event_destination_list_params import (
        EventDestinationListParams as EventDestinationListParams,
    )
    from stripe.params.v2.core._event_destination_ping_params import (
        EventDestinationPingParams as EventDestinationPingParams,
    )
    from stripe.params.v2.core._event_destination_retrieve_params import (
        EventDestinationRetrieveParams as EventDestinationRetrieveParams,
    )
    from stripe.params.v2.core._event_destination_update_params import (
        EventDestinationUpdateParams as EventDestinationUpdateParams,
        EventDestinationUpdateParamsWebhookEndpoint as EventDestinationUpdateParamsWebhookEndpoint,
    )
    from stripe.params.v2.core._event_list_params import (
        EventListParams as EventListParams,
        EventListParamsCreated as EventListParamsCreated,
    )
    from stripe.params.v2.core._event_retrieve_params import (
        EventRetrieveParams as EventRetrieveParams,
    )
    from stripe.params.v2.core._fee_batch_list_params import (
        FeeBatchListParams as FeeBatchListParams,
    )
    from stripe.params.v2.core._fee_batch_retrieve_params import (
        FeeBatchRetrieveParams as FeeBatchRetrieveParams,
    )
    from stripe.params.v2.core._fee_entry_list_params import (
        FeeEntryListParams as FeeEntryListParams,
    )
    from stripe.params.v2.core._fee_entry_retrieve_params import (
        FeeEntryRetrieveParams as FeeEntryRetrieveParams,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "accounts": ("stripe.params.v2.core.accounts", True),
    "health": ("stripe.params.v2.core.health", True),
    "vault": ("stripe.params.v2.core.vault", True),
    "AccountCloseParams": (
        "stripe.params.v2.core._account_close_params",
        False,
    ),
    "AccountCreateParams": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfiguration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreator": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercial": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThird": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLead": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripe": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumer": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCeltic": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBank": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLead": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomer": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerAutomaticIndirectTax": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBilling": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBillingInvoice": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBillingInvoiceRendering": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerShipping": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerShippingAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchant": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantBacsDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantBranding": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCardPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCardPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesP24PaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesP24PaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesZipPaymentsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesZipPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCardPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantKonbiniPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupport": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupportHours": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantScriptStatementDescriptor": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantSmartDisputes": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantSmartDisputesAutoRespond": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantStatementDescriptor": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantSupport": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantSupportAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManager": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorage": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInbound": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAud": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCad": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEur": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbp": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsd": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdc": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutbound": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAud": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCad": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEur": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbp": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsd": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdc": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorage": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInbound": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsd": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdc": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutbound": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsd": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdc": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfers": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCards": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWallets": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecks": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfers": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWallets": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCredits": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWallets": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebits": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMoneyManagerRegulatedActivity": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipient": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccounts": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAch": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecs": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEft": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwire": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFps": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstant": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocal": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNpp": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtp": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCredit": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstant": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwift": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWire": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesCards": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesCardsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesCardsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWallets": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecks": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecksProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecksProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtections": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtectionsPspMigration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsDefaults": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsDefaultsProfile": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsDefaultsResponsibilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentity": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestations": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsDirectorshipDeclaration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsOwnershipDeclaration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsPersonsProvided": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsRepresentativeDeclaration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfService": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceAccount": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreator": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThird": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdApplePay": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardFinancingDisclosures": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumer": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerAccountHolder": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCeltic": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticApplePay": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardFinancingDisclosures": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBank": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardFinancingDisclosures": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerGlobalAccountHolder": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLead": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardFinancingDisclosures": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCard": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardBankTerms": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardFinancingDisclosures": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardPlatform": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceConsumerMoneyManager": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceConsumerPrivacyDisclosures": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceMoneyManager": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetails": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsAnnualRevenue": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocuments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsIdNumber": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsRegistrationDate": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptAddresses": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptNames": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptNamesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividual": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualAdditionalAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualAdditionalName": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDateOfBirth": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocuments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsPassport": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsVisa": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualIdNumber": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualRelationship": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptAddresses": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptAddressesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptAddressesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptNames": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptNamesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptNamesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountEvaluationCreateParams": (
        "stripe.params.v2.core._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsAccountData": (
        "stripe.params.v2.core._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsAccountDataDefaults": (
        "stripe.params.v2.core._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsAccountDataDefaultsProfile": (
        "stripe.params.v2.core._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsAccountDataIdentity": (
        "stripe.params.v2.core._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsAccountDataIdentityBusinessDetails": (
        "stripe.params.v2.core._account_evaluation_create_params",
        False,
    ),
    "AccountLinkCreateParams": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCase": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountOnboarding": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountUpdate": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseRecipientOnboarding": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseRecipientOnboardingCollectionOptions": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseRecipientUpdate": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseRecipientUpdateCollectionOptions": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountListParams": ("stripe.params.v2.core._account_list_params", False),
    "AccountRetrieveParams": (
        "stripe.params.v2.core._account_retrieve_params",
        False,
    ),
    "AccountTokenCreateParams": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentity": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestations": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsDirectorshipDeclaration": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsOwnershipDeclaration": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsPersonsProvided": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsRepresentativeDeclaration": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfService": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceAccount": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreator": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceMoneyManager": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetails": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsAnnualRevenue": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocuments": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsIdNumber": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsRegistrationDate": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptAddresses": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKana": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKanji": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptNames": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKana": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKanji": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividual": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualAdditionalAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualAdditionalName": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDateOfBirth": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocuments": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsCompanyAuthorization": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsPassport": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsVisa": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualIdNumber": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualRelationship": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptAddresses": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptAddressesKana": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptAddressesKanji": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptNames": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptNamesKana": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptNamesKanji": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenRetrieveParams": (
        "stripe.params.v2.core._account_token_retrieve_params",
        False,
    ),
    "AccountUpdateParams": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfiguration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreator": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercial": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThird": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLead": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripe": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumer": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCeltic": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBank": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLead": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomer": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBilling": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBillingInvoice": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerShipping": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerShippingAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchant": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantBacsDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantBranding": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCardPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCardPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesP24PaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesP24PaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesZipPaymentsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesZipPaymentsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCardPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantKonbiniPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupport": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupportHours": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantScriptStatementDescriptor": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantSmartDisputes": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantSmartDisputesAutoRespond": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantStatementDescriptor": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantSupport": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantSupportAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManager": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorage": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInbound": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAud": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCad": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEur": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbp": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsd": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdc": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutbound": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAud": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCad": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEur": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbp": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsd": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdc": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorage": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInbound": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsd": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdc": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutbound": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsd": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdc": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesInboundTransfers": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCards": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWallets": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecks": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfers": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWallets": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCredits": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWallets": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedDebits": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMoneyManagerRegulatedActivity": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipient": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccounts": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsAch": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsBecs": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsEft": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFedwire": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFps": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsInstant": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocal": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsNpp": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsRtp": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCredit": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstant": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSwift": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWire": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesCards": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesCardsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesCardsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWallets": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesPaperChecks": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesPaperChecksProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesPaperChecksProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtections": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtectionsPspMigration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsDefaults": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsDefaultsProfile": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsDefaultsResponsibilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentity": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestations": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsOwnershipDeclaration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsPersonsProvided": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsRepresentativeDeclaration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfService": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreator": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThird": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdApplePay": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumer": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerAccountHolder": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCeltic": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticApplePay": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardFinancingDisclosures": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBank": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardFinancingDisclosures": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerGlobalAccountHolder": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLead": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadApplePay": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardFinancingDisclosures": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCard": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardBankTerms": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardFinancingDisclosures": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardPlatform": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceConsumerMoneyManager": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceConsumerPrivacyDisclosures": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceMoneyManager": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetails": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocuments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsIdNumber": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsRegistrationDate": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptAddresses": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptNames": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividual": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualAdditionalAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualAdditionalName": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDateOfBirth": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocuments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsPassport": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsVisa": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualIdNumber": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualRelationship": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptAddresses": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptAddressesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptAddressesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptNames": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptNamesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptNamesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "ApprovalRequestCancelParams": (
        "stripe.params.v2.core._approval_request_cancel_params",
        False,
    ),
    "ApprovalRequestExecuteParams": (
        "stripe.params.v2.core._approval_request_execute_params",
        False,
    ),
    "ApprovalRequestListParams": (
        "stripe.params.v2.core._approval_request_list_params",
        False,
    ),
    "ApprovalRequestRetrieveParams": (
        "stripe.params.v2.core._approval_request_retrieve_params",
        False,
    ),
    "ApprovalRequestSubmitParams": (
        "stripe.params.v2.core._approval_request_submit_params",
        False,
    ),
    "BatchJobCancelParams": (
        "stripe.params.v2.core._batch_job_cancel_params",
        False,
    ),
    "BatchJobCreateParams": (
        "stripe.params.v2.core._batch_job_create_params",
        False,
    ),
    "BatchJobCreateParamsEndpoint": (
        "stripe.params.v2.core._batch_job_create_params",
        False,
    ),
    "BatchJobCreateParamsNotificationSuppression": (
        "stripe.params.v2.core._batch_job_create_params",
        False,
    ),
    "BatchJobRetrieveParams": (
        "stripe.params.v2.core._batch_job_retrieve_params",
        False,
    ),
    "ClaimableSandboxCreateParams": (
        "stripe.params.v2.core._claimable_sandbox_create_params",
        False,
    ),
    "ClaimableSandboxCreateParamsOnboardingLinkDetails": (
        "stripe.params.v2.core._claimable_sandbox_create_params",
        False,
    ),
    "ClaimableSandboxCreateParamsPrefill": (
        "stripe.params.v2.core._claimable_sandbox_create_params",
        False,
    ),
    "ClaimableSandboxRenewOnboardingLinkParams": (
        "stripe.params.v2.core._claimable_sandbox_renew_onboarding_link_params",
        False,
    ),
    "ClaimableSandboxRenewOnboardingLinkParamsOnboardingLinkDetails": (
        "stripe.params.v2.core._claimable_sandbox_renew_onboarding_link_params",
        False,
    ),
    "ClaimableSandboxRetrieveParams": (
        "stripe.params.v2.core._claimable_sandbox_retrieve_params",
        False,
    ),
    "ConnectionSessionCreateParams": (
        "stripe.params.v2.core._connection_session_create_params",
        False,
    ),
    "ConnectionSessionRetrieveParams": (
        "stripe.params.v2.core._connection_session_retrieve_params",
        False,
    ),
    "EventDestinationCreateParams": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationCreateParamsAmazonEventbridge": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationCreateParamsAzureEventGrid": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationCreateParamsWebhookEndpoint": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationDeleteParams": (
        "stripe.params.v2.core._event_destination_delete_params",
        False,
    ),
    "EventDestinationDisableParams": (
        "stripe.params.v2.core._event_destination_disable_params",
        False,
    ),
    "EventDestinationEnableParams": (
        "stripe.params.v2.core._event_destination_enable_params",
        False,
    ),
    "EventDestinationListParams": (
        "stripe.params.v2.core._event_destination_list_params",
        False,
    ),
    "EventDestinationPingParams": (
        "stripe.params.v2.core._event_destination_ping_params",
        False,
    ),
    "EventDestinationRetrieveParams": (
        "stripe.params.v2.core._event_destination_retrieve_params",
        False,
    ),
    "EventDestinationUpdateParams": (
        "stripe.params.v2.core._event_destination_update_params",
        False,
    ),
    "EventDestinationUpdateParamsWebhookEndpoint": (
        "stripe.params.v2.core._event_destination_update_params",
        False,
    ),
    "EventListParams": ("stripe.params.v2.core._event_list_params", False),
    "EventListParamsCreated": (
        "stripe.params.v2.core._event_list_params",
        False,
    ),
    "EventRetrieveParams": (
        "stripe.params.v2.core._event_retrieve_params",
        False,
    ),
    "FeeBatchListParams": (
        "stripe.params.v2.core._fee_batch_list_params",
        False,
    ),
    "FeeBatchRetrieveParams": (
        "stripe.params.v2.core._fee_batch_retrieve_params",
        False,
    ),
    "FeeEntryListParams": (
        "stripe.params.v2.core._fee_entry_list_params",
        False,
    ),
    "FeeEntryRetrieveParams": (
        "stripe.params.v2.core._fee_entry_retrieve_params",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()
